# Environments — Mobile Manipulation

The mobile manipulation environments of the Space Robotics Bench represent a challenging combination of mobility and manipulation capabilities.

## Ground-based Mobile Manipulation

### Mobile Excavation (`mobile_excavation`)

> Excavation of granular material (regolith) with a ground-based mobile manipulator

<iframe style="width:100%;aspect-ratio:16/9" src="https://www.youtube.com/embed/T7nt1grwHic?si=SAljCvdWv3Z-x-eh&mute=1&autoplay=1&loop=1&playlist=T7nt1grwHic" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture; web-share" referrerpolicy="strict-origin-when-cross-origin" allowfullscreen></iframe>

<!-- ## Aerial Mobile Manipulation -->

## Orbital Mobile Manipulation

### Mobile Debris Capture (`mobile_debris_capture`)

> Capture of floating debris in microgravity with a floating-base mobile manipulator

<iframe style="width:100%;aspect-ratio:16/9" src="https://www.youtube.com/embed/kZIWWPn2EQQ?si=Rkjo5ZvP6_irIexi&mute=1&autoplay=1&loop=1&playlist=kZIWWPn2EQQ" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture; web-share" referrerpolicy="strict-origin-when-cross-origin" allowfullscreen></iframe>
